@@ -5,7 +5,7 @@ use warnings;
 package Meerkat;
 # ABSTRACT: Manage MongoDB documents as Moose objects
 
-our $VERSION = '0.012';
+our $VERSION = '0.014';
 
 # Dependencies
 use Moose 2;
@@ -177,7 +177,7 @@ Meerkat - Manage MongoDB documents as Moose objects
 
 =head1 VERSION
 
-version 0.012
+version 0.014
 
 =head1 SYNOPSIS
 
@@ -518,9 +518,9 @@ David Golden <dagolden@cpan.org>
 
 =head1 CONTRIBUTOR
 
-=for stopwords David Golden
+=for stopwords Todd Bruner
 
-David Golden <xdg@xdg.me>
+Todd Bruner <todd.bruner@gmail.com>
 
 =head1 COPYRIGHT AND LICENSE
 
