@@ -5,7 +5,7 @@ use warnings;
 package Meerkat::Cursor;
 # ABSTRACT: Wrap MongoDB::Cursor to inflate data to objects
 
-our $VERSION = '0.012';
+our $VERSION = '0.014';
 
 # Dependencies
 use Moose 2;
@@ -23,7 +23,7 @@ has cursor => (
     required => 1,
     handles  => [
         qw( fields sort limit tailable skip snapshot hint ),
-        qw( explain count reset has_next next info all ),
+        qw( explain count reset has_next next info all immortal),
     ],
 );
 
@@ -74,7 +74,7 @@ Meerkat::Cursor - Wrap MongoDB::Cursor to inflate data to objects
 
 =head1 VERSION
 
-version 0.012
+version 0.014
 
 =head1 SYNOPSIS
 
